@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.104 2010/06/03 12:45:57 bowkenken Exp $
+* $Id: amenu.c,v 1.105 2010/06/04 11:57:29 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -379,6 +379,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+		ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_NULL;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
 				MSG_TTL_AUTO_MARK_MAX_BYTE );
@@ -509,7 +510,9 @@ void	set_dflt_auto_mark_mbr( long ls_mbr_n )
 
 	for( n = DFLT_AUTO_MARK_NULL + 1; n < DFLT_AUTO_MARK_MAX_N; n++ ){
 		p = srch_dflt_auto_mark( ls_mbr_n, (dflt_auto_mark_t)n );
-		set_dflt_auto_mark( ls_mbr_n, p );
+		if( p != NULL ){
+			set_dflt_auto_mark( ls_mbr_n, p );
+		}
 	}
 }
 
@@ -772,15 +775,67 @@ void	ver_up_auto_mark_1_2_35( void )
 	auto_mark_t	*p;
 	long	n, m;
 	long	ls_mbr_n;
+	const char	*name;
 
 	/* ǥեȤκɲ */
 
 	for( n = DFLT_AUTO_MARK_NULL + 1; n < DFLT_AUTO_MARK_MAX_N; n++ ){
 		m = AUTO_MARK_MAX_N - (DFLT_AUTO_MARK_MAX_N - n);
+		ls_flg_ena_auto_mark[m] = TRUE;
 		for( ls_mbr_n = 0; ls_mbr_n < LS_MBR_MAX_N; ls_mbr_n++ ){
 			p = &(ls_auto_mark[ls_mbr_n][m]);
+			p->dflt = (dflt_auto_mark_t)n;
 			set_dflt_auto_mark( ls_mbr_n, p );
 		}
+
+		name = MSG_NAME_DFLT_AUTO_MARK_CLEAR;
+		switch( n ){
+		case DFLT_AUTO_MARK_NULL:
+		case DFLT_AUTO_MARK_MAX_N:
+			break;
+		case DFLT_AUTO_MARK_FIGHT:
+			/* Ʈ(ɲ) */
+			name = MSG_NAME_DFLT_AUTO_MARK_FIGHT;
+			break;
+		case DFLT_AUTO_MARK_FIGHT_PRIO:
+			/* Ʈ() */
+			name = MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO;
+			break;
+		case DFLT_AUTO_MARK_FIGHT_NO_THROW:
+			/* ܶƮ(ɲ) */
+			name = MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW;
+			break;
+		case DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO:
+			/* ܶƮ() */
+			name = MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO;
+			break;
+		case DFLT_AUTO_MARK_FIGHT_ALL:
+			/* (ɲ) */
+			name = MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL;
+			break;
+		case DFLT_AUTO_MARK_FIGHT_ALL_PRIO:
+			/* () */
+			name = MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO;
+			break;
+		case DFLT_AUTO_MARK_ITEM_ALL:
+			/* ƤΥƥ */
+			name = MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL;
+			break;
+		case DFLT_AUTO_MARK_ITEM_OWN:
+			/* äƤ륢ƥ */
+			name = MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN;
+			break;
+		case DFLT_AUTO_MARK_RETREAT:
+			/*  */
+			name = MSG_NAME_DFLT_AUTO_MARK_RETREAT;
+			break;
+		case DFLT_AUTO_MARK_CLEAR:
+			/*  */
+			name = MSG_NAME_DFLT_AUTO_MARK_CLEAR;
+			break;
+		}
+		str_nz_cpy( msg_ttl_auto_mark[m], name,
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	/* Ƭ¤ؤ */
