@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-gconf.c,v 1.2 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: gf-gconf.c,v 1.5 2010/05/16 19:34:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -66,7 +66,7 @@ bool_t	load_graph_conf( char *path )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GRAPH_CONF_VER_MJR,
 			GRAPH_CONF_VER_MNR,
 			GRAPH_CONF_VER_PAT ) ){
@@ -417,3 +417,11 @@ bool_t	load_graph_conf_set_str(
 	return TRUE;
 #endif
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_gf_gconf_c( void )
+{
+}
