@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.72 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: gmain.h,v 1.73 2010/02/23 16:47:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -165,16 +165,25 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
+/* ΥХåե򥪥ץǻꤵ줿? */
+EXTERN long	g_audio_buf_siz_arg_overwrite;
+
+/* ΥХåե򥪥ץǻ */
+EXTERN long	g_audio_buf_siz_arg;
+
+/* ΥХåե */
+EXTERN long g_audio_buf_siz;
+
 /* ɥɸ򥪥ץǻꤵ줿? */
 EXTERN bool_t	g_flg_win_pos_arg_overwrite;
 
-/* ɥޥ͡㤬 GNOME 򥪥ץǻꤵ줿? */
+/* ɥޥ͡㤬 GNOME 򥪥ץǻ */
 EXTERN bool_t	g_flg_gnome_arg;
 
 /* ɥޥ͡㤬 GNOME ? */
 EXTERN bool_t	g_flg_gnome;
 
-/* ɥɽ˰֤ꤹ뤫򥪥ץǻꤵ줿? */
+/* ɥɽ˰֤ꤹ뤫򥪥ץǻ */
 EXTERN bool_t	g_flg_set_win_pos_arg;
 
 /* ɥɽ˰֤ꤹ뤫? */
