@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.154 2009/09/04 15:26:28 bowkenken Exp $
+* $Id: tmenu.c,v 1.159 2010/05/29 14:37:00 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -33,6 +33,8 @@
 
 /**/
 
+/* ذưʤɤǥ˥塼ꥻåȤ뤫? */
+#define	FLG_RESET_MENU	0
 /* ˡȤʤƤ⥮ɤ뤫? */
 #define	FLG_CAN_ENTER_MAGIC_GUILD_NOT_LEARNED	TRUE
 
@@ -109,12 +111,16 @@ void	init_town_menu( void )
 
 void	reset_static_town_menu( void )
 {
-	party_t	*pty = get_party();
-	mbr_t	**ls_mbr = get_ls_mbr();
 	long	i;
 
-	g_sel_mbr = pty->mbr[0];
-	g_sel_ls_mbr = ls_mbr[0];
+#if	FLG_RESET_MENU
+	{
+		party_t	*pty = get_party();
+		mbr_t	**ls_mbr = get_ls_mbr();
+		g_sel_mbr = pty->mbr[0];
+		g_sel_ls_mbr = ls_mbr[0];
+	}
+#endif
 	g_shop_n = SHOP_N_NULL;
 	g_deal_kind = DEAL_KIND_BUY;
 	g_sel_art = NULL;
@@ -123,7 +129,9 @@ void	reset_static_town_menu( void )
 	for( i = 0; i < MBR_MAX_N; i++ )
 		g_mbr_order[i] = NULL;
 
+#if	FLG_RESET_MENU
 	g_navi_dflt = NULL;
+#endif
 
 	/**/
 
@@ -211,10 +219,10 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 
 	max_len = 1;
 	for( p = *pp; p->path[0] != '\0'; p++ ){
-		long	tmp_len;
+		if( strcmp( p->kind, "<Item>" ) != 0 )
+			continue;
 
-		tmp_len = str_len_draw( MSG( p->n_msg ) );
-		max_len = max_l( max_len, tmp_len );
+		max_len = max_l( max_len, str_len_draw( MSG( p->n_msg ) ) );
 	}
 
 	p = srch_menu( *pp, "title" );
@@ -2266,6 +2274,7 @@ bool_t	exec_menu_new_mbr( void )
 	while( 1 ){
 		menu_mbr_data( ls_mbr[n], &page_n, &data_n,
 				MBR_DATA_EDIT_KIND_NEW );
+		exec_menu_position( ls_mbr[n] );
 
 		ask = exec_menu_ask( MSG_TTL_MENU_ASK_NEW_MBR,
 				ASK_NO, TRUE );
@@ -3288,11 +3297,17 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 {
 	party_t	*pty = get_party();
 	bool_t	flg_short;
+	stay_inn_kind_t	kind;
 	gold_t	price;
 	bool_t	flg_pay;
 	long	mbr_n;
 
 	flg_short = (bool_t)(long)((*pp)->arg);
+	if( flg_short )
+		kind = STAY_INN_KIND_SHORT;
+	else
+		kind = STAY_INN_KIND_LONG;
+
 	price = get_price_inn( flg_short );
 
 	flg_pay = TRUE;
@@ -3323,7 +3338,7 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 	}
 
 	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_INN );
-	stay_inn( flg_short, FALSE );
+	stay_inn( kind );
 
 	return STR_MENU_CANCEL;
 }
@@ -3340,7 +3355,7 @@ char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt )
 char	*cb_menu_inn_stay_in_mews( menu_t **pp, menu_t **dflt )
 {
 	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_INN );
-	stay_inn( FALSE, TRUE );
+	stay_inn( STAY_INN_KIND_MEWS );
 
 	return STR_MENU_CANCEL;
 }
@@ -3390,6 +3405,8 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		if( ls[i].path[0] == '\0' )
 			break;
+		if( ls[i].arg == NULL )
+			continue;
 
 		kind = (spell_kind_t)(long)(ls[i].arg);
 		tab = get_spell_tab( kind );
